==> xoonips-3.48.zip: xoonips-3.48/itemtypes/xnppaper/language/ja_utf8/modinfo.php <==
<?php
// $Revision: 1.1.2.4 $
// ------------------------------------------------------------------------- //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2011 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
// ------------------------------------------------------------------------- //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
// ------------------------------------------------------------------------- //
/* constant strings
 * $Revision: 1.1.2.4 $
 */

// _MI_<MODULENAME>_<STRINGNAME>

// The name of this module
define("_MI_XNPPAPER_NAME","XooNIps Paper Item Type Module");
// A brief description of this module
define("_MI_XNPPAPER_DESC","XooNIps Paper Item Type Module");

// Names of admin menu items
define("_MI_XNPPAPER_CFG_SHOW_PDF",     "PDF Reprint の公開レベル");
define("_MI_XNPPAPER_CFG_SHOW_PDF_DESC","");
define("_MI_XNPPAPER_CFG_SHOW_ABST",     "Abstract の公開レベル");
define("_MI_XNPPAPER_CFG_SHOW_ABST_D","");

?>

==> xoonips-3.49.zip: xoonips-3.49/itemtypes/xnppaper/language/ja_utf8/modinfo.php <==
<?php

// ------------------------------------------------------------------------- //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2011 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
// ------------------------------------------------------------------------- //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
// ------------------------------------------------------------------------- //
/* constant strings
 */

// _MI_<MODULENAME>_<STRINGNAME>

// The name of this module
define('_MI_XNPPAPER_NAME', 'XooNIps Paper Item Type Module');
// A brief description of this module
define('_MI_XNPPAPER_DESC', 'XooNIps Paper Item Type Module');

// Names of admin menu items
define('_MI_XNPPAPER_CFG_SHOW_PDF', 'PDF Reprint の公開レベル');
define('_MI_XNPPAPER_CFG_SHOW_PDF_DESC', '');
define('_MI_XNPPAPER_CFG_SHOW_ABST', 'Abstract の公開レベル');
define('_MI_XNPPAPER_CFG_SHOW_ABST_D', '');
